from __future__ import annotations

from typing import TYPE_CHECKING

import config
from path import Path

if TYPE_CHECKING:
    from photodown import Photodown

from jinja2 import Environment, FileSystemLoader

env = Environment(loader=FileSystemLoader('src/templates'))
page_template = env.get_template('page.jinja')
class Page:
    
    def __init__(self, path: Path, markdown: Photodown):
        self._path: Path = path
        self._html: Path = Path(self._path.get_absolute_path()[:-len(config.PAGE_EXT)] + ".html")
        self._markdown: Photodown = markdown
        with open(path.get_absolute_path(), "r") as f:
            self._raw_content: str = f.read()

    def _get_content(self):
        content = self._markdown.render(self._raw_content)
        return content
    
    def _to_html(self) -> str:
        html: str = page_template.render(content=self._get_content())
        return html

    def create(self) -> Path:
        with open(self._html.get_absolute_path(), "w") as f:
            f.write(self._to_html())